@@ -195,7 +195,7 @@ void Process::setState (State newstate) {
     }
 }
 
-KDE_NO_EXPORT void Process::rescheduledStateChanged () {
+TDE_NO_EXPORT void Process::rescheduledStateChanged () {
     State old_state = m_old_state;
     m_old_state = m_state;
     m_source->stateChange (this, old_state, m_state);
@@ -273,7 +273,7 @@ KDE_NO_CDTOR_EXPORT MPlayerBase::MPlayerBase (TQObject * parent, Settings * sett
 KDE_NO_CDTOR_EXPORT MPlayerBase::~MPlayerBase () {
 }
 
-KDE_NO_EXPORT void MPlayerBase::initProcess (Viewer * viewer) {
+TDE_NO_EXPORT void MPlayerBase::initProcess (Viewer * viewer) {
     Process::initProcess (viewer);
     const KURL & url (m_source->url ());
     if (!url.isEmpty ()) {
@@ -287,7 +287,7 @@ KDE_NO_EXPORT void MPlayerBase::initProcess (Viewer * viewer) {
             this, TQ_SLOT (processStopped (TDEProcess *)));
 }
 
-KDE_NO_EXPORT bool MPlayerBase::sendCommand (const TQString & cmd) {
+TDE_NO_EXPORT bool MPlayerBase::sendCommand (const TQString & cmd) {
     if (playing () && m_use_slave) {
         commands.push_front (cmd + '\n');
         fprintf (stderr, "eval %s", commands.last ().latin1 ());
@@ -299,14 +299,14 @@ KDE_NO_EXPORT bool MPlayerBase::sendCommand (const TQString & cmd) {
     return false;
 }
 
-KDE_NO_EXPORT bool MPlayerBase::stop () {
+TDE_NO_EXPORT bool MPlayerBase::stop () {
     terminateJobs ();
     if (!m_source || !m_process || !m_process->isRunning ())
         return true;
     return true;
 }
 
-KDE_NO_EXPORT bool MPlayerBase::quit () {
+TDE_NO_EXPORT bool MPlayerBase::quit () {
     if (playing ()) {
         stop ();
         disconnect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
@@ -333,7 +333,7 @@ KDE_NO_EXPORT bool MPlayerBase::quit () {
     return Process::quit ();
 }
 
-KDE_NO_EXPORT void MPlayerBase::dataWritten (TDEProcess *) {
+TDE_NO_EXPORT void MPlayerBase::dataWritten (TDEProcess *) {
     if (!commands.size ()) return;
     kdDebug() << "eval done " << commands.last () << endl;
     commands.pop_back ();
@@ -342,7 +342,7 @@ KDE_NO_EXPORT void MPlayerBase::dataWritten (TDEProcess *) {
                              commands.last ().length ());
 }
 
-KDE_NO_EXPORT void MPlayerBase::processStopped (TDEProcess *) {
+TDE_NO_EXPORT void MPlayerBase::processStopped (TDEProcess *) {
     kdDebug() << "process stopped" << endl;
     commands.clear ();
     setState (Ready);
@@ -370,24 +370,24 @@ KDE_NO_CDTOR_EXPORT MPlayer::~MPlayer () {
     delete m_configpage;
 }
 
-KDE_NO_EXPORT void MPlayer::init () {
+TDE_NO_EXPORT void MPlayer::init () {
 }
 
 TQString MPlayer::menuName () const {
     return i18n ("&MPlayer");
 }
 
-KDE_NO_EXPORT WId MPlayer::widget () {
+TDE_NO_EXPORT WId MPlayer::widget () {
     return viewer ()->embeddedWinId ();
 }
 
-KDE_NO_EXPORT bool MPlayer::ready (Viewer * viewer) {
+TDE_NO_EXPORT bool MPlayer::ready (Viewer * viewer) {
     Process::ready (viewer);
     viewer->changeProtocol (QXEmbed::XPLAIN);
     return false;
 }
 
-KDE_NO_EXPORT bool MPlayer::deMediafiedPlay () {
+TDE_NO_EXPORT bool MPlayer::deMediafiedPlay () {
     if (playing ())
         return sendCommand (TQString ("gui_play"));
     if (!m_needs_restarted && playing ())
@@ -448,7 +448,7 @@ KDE_NO_EXPORT bool MPlayer::deMediafiedPlay () {
     return run (args.ascii (), m_source->pipeCmd ().ascii ());
 }
 
-KDE_NO_EXPORT bool MPlayer::stop () {
+TDE_NO_EXPORT bool MPlayer::stop () {
     terminateJobs ();
     if (!m_source || !m_process || !m_process->isRunning ()) return true;
     if (m_use_slave)
@@ -456,11 +456,11 @@ KDE_NO_EXPORT bool MPlayer::stop () {
     return MPlayerBase::stop ();
 }
 
-KDE_NO_EXPORT bool MPlayer::pause () {
+TDE_NO_EXPORT bool MPlayer::pause () {
     return sendCommand (TQString ("pause"));
 }
 
-KDE_NO_EXPORT bool MPlayer::seek (int pos, bool absolute) {
+TDE_NO_EXPORT bool MPlayer::seek (int pos, bool absolute) {
     if (!m_source || !m_source->hasLength () ||
             (absolute && m_source->position () == pos))
         return false;
@@ -487,7 +487,7 @@ KDE_NO_EXPORT bool MPlayer::seek (int pos, bool absolute) {
     return sendCommand (cmd);
 }
 
-KDE_NO_EXPORT bool MPlayer::volume (int incdec, bool absolute) {
+TDE_NO_EXPORT bool MPlayer::volume (int incdec, bool absolute) {
     if (absolute)
         incdec -= old_volume;
     if (incdec == 0)
@@ -496,25 +496,25 @@ KDE_NO_EXPORT bool MPlayer::volume (int incdec, bool absolute) {
     return sendCommand (TQString ("volume ") + TQString::number (incdec));
 }
 
-KDE_NO_EXPORT bool MPlayer::saturation (int val, bool absolute) {
+TDE_NO_EXPORT bool MPlayer::saturation (int val, bool absolute) {
     TQString cmd;
     cmd.sprintf ("saturation %d %d", val, absolute ? 1 : 0);
     return sendCommand (cmd);
 }
 
-KDE_NO_EXPORT bool MPlayer::hue (int val, bool absolute) {
+TDE_NO_EXPORT bool MPlayer::hue (int val, bool absolute) {
     TQString cmd;
     cmd.sprintf ("hue %d %d", val, absolute ? 1 : 0);
     return sendCommand (cmd);
 }
 
-KDE_NO_EXPORT bool MPlayer::contrast (int val, bool /*absolute*/) {
+TDE_NO_EXPORT bool MPlayer::contrast (int val, bool /*absolute*/) {
     TQString cmd;
     cmd.sprintf ("contrast %d 1", val);
     return sendCommand (cmd);
 }
 
-KDE_NO_EXPORT bool MPlayer::brightness (int val, bool /*absolute*/) {
+TDE_NO_EXPORT bool MPlayer::brightness (int val, bool /*absolute*/) {
     TQString cmd;
     cmd.sprintf ("brightness %d 1", val);
     return sendCommand (cmd);
@@ -629,7 +629,7 @@ bool MPlayer::run (const char * args, const char * pipe) {
     return false;
 }
 
-KDE_NO_EXPORT bool MPlayer::grabPicture (const KURL & url, int pos) {
+TDE_NO_EXPORT bool MPlayer::grabPicture (const KURL & url, int pos) {
     stop ();
     initProcess (viewer ());
     TQString outdir = locateLocal ("data", "kmplayer/");
@@ -652,7 +652,7 @@ KDE_NO_EXPORT bool MPlayer::grabPicture (const KURL & url, int pos) {
     return m_process->isRunning ();
 }
 
-KDE_NO_EXPORT void MPlayer::processOutput (TDEProcess *, char * str, int slen) {
+TDE_NO_EXPORT void MPlayer::processOutput (TDEProcess *, char * str, int slen) {
     if (!viewer () || slen <= 0) return;
     View * v = viewer ()->view ();
 
@@ -809,7 +809,7 @@ KDE_NO_EXPORT void MPlayer::processOutput (TDEProcess *, char * str, int slen) {
     } while (slen > 0);
 }
 
-KDE_NO_EXPORT void MPlayer::processStopped (TDEProcess * p) {
+TDE_NO_EXPORT void MPlayer::processStopped (TDEProcess * p) {
     if (p && !m_grabfile.isEmpty ()) {
         emit grabReady (m_grabfile);
         m_grabfile.truncate (0);
@@ -926,7 +926,7 @@ KDE_NO_CDTOR_EXPORT MPlayerPreferencesPage::MPlayerPreferencesPage (MPlayer * p)
  : m_process (p), m_configframe (0L) {
 }
 
-KDE_NO_EXPORT void MPlayerPreferencesPage::write (TDEConfig * config) {
+TDE_NO_EXPORT void MPlayerPreferencesPage::write (TDEConfig * config) {
     config->setGroup (strMPlayerPatternGroup);
     for (int i = 0; i < int (pat_last); i++)
         config->writeEntry
@@ -938,7 +938,7 @@ KDE_NO_EXPORT void MPlayerPreferencesPage::write (TDEConfig * config) {
     config->writeEntry (strAlwaysBuildIndex, alwaysbuildindex);
 }
 
-KDE_NO_EXPORT void MPlayerPreferencesPage::read (TDEConfig * config) {
+TDE_NO_EXPORT void MPlayerPreferencesPage::read (TDEConfig * config) {
     config->setGroup (strMPlayerPatternGroup);
     for (int i = 0; i < int (pat_last); i++)
         m_patterns[i].setPattern (config->readEntry
@@ -950,7 +950,7 @@ KDE_NO_EXPORT void MPlayerPreferencesPage::read (TDEConfig * config) {
     alwaysbuildindex = config->readBoolEntry (strAlwaysBuildIndex, false);
 }
 
-KDE_NO_EXPORT void MPlayerPreferencesPage::sync (bool fromUI) {
+TDE_NO_EXPORT void MPlayerPreferencesPage::sync (bool fromUI) {
     TQTable * table = m_configframe->table;
     TQSpinBox * cacheSize = static_cast<TQSpinBox *>(table->cellWidget (2, 1));
     TQCheckBox * buildIndex = static_cast<TQCheckBox *>(table->cellWidget (3, 1));
@@ -972,13 +972,13 @@ KDE_NO_EXPORT void MPlayerPreferencesPage::sync (bool fromUI) {
     }
 }
 
-KDE_NO_EXPORT void MPlayerPreferencesPage::prefLocation (TQString & item, TQString & icon, TQString & tab) {
+TDE_NO_EXPORT void MPlayerPreferencesPage::prefLocation (TQString & item, TQString & icon, TQString & tab) {
     item = i18n ("General Options");
     icon = TQString ("kmplayer");
     tab = i18n ("MPlayer");
 }
 
-KDE_NO_EXPORT TQFrame * MPlayerPreferencesPage::prefPage (TQWidget * parent) {
+TDE_NO_EXPORT TQFrame * MPlayerPreferencesPage::prefPage (TQWidget * parent) {
     m_configframe = new MPlayerPreferencesFrame (parent);
     return m_configframe;
 }
@@ -997,7 +997,7 @@ KDE_NO_CDTOR_EXPORT MEncoder::MEncoder (TQObject * parent, Settings * settings)
 KDE_NO_CDTOR_EXPORT MEncoder::~MEncoder () {
 }
 
-KDE_NO_EXPORT void MEncoder::init () {
+TDE_NO_EXPORT void MEncoder::init () {
 }
 
 bool MEncoder::deMediafiedPlay () {
@@ -1038,7 +1038,7 @@ bool MEncoder::deMediafiedPlay () {
     return success;
 }
 
-KDE_NO_EXPORT bool MEncoder::stop () {
+TDE_NO_EXPORT bool MEncoder::stop () {
     terminateJobs ();
     if (!m_source || !m_process || !m_process->isRunning ()) return true;
     kdDebug () << "MEncoder::stop ()" << endl;
@@ -1062,7 +1062,7 @@ MPlayerDumpstream::MPlayerDumpstream (TQObject * parent, Settings * settings)
 KDE_NO_CDTOR_EXPORT MPlayerDumpstream::~MPlayerDumpstream () {
 }
 
-KDE_NO_EXPORT void MPlayerDumpstream::init () {
+TDE_NO_EXPORT void MPlayerDumpstream::init () {
 }
 
 bool MPlayerDumpstream::deMediafiedPlay () {
@@ -1100,7 +1100,7 @@ bool MPlayerDumpstream::deMediafiedPlay () {
     return success;
 }
 
-KDE_NO_EXPORT bool MPlayerDumpstream::stop () {
+TDE_NO_EXPORT bool MPlayerDumpstream::stop () {
     terminateJobs ();
     if (!m_source || !m_process || !m_process->isRunning ()) return true;
     kdDebug () << "MPlayerDumpstream::stop ()" << endl;
@@ -1435,12 +1435,12 @@ void CallbackProcess::initProcess (Viewer * viewer) {
             this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
 }
 
-KDE_NO_EXPORT void CallbackProcess::processOutput (TDEProcess *, char * str, int slen) {
+TDE_NO_EXPORT void CallbackProcess::processOutput (TDEProcess *, char * str, int slen) {
     if (viewer () && slen > 0)
         viewer ()->view ()->addText (TQString::fromLocal8Bit (str, slen));
 }
 
-KDE_NO_EXPORT void CallbackProcess::processStopped (TDEProcess *) {
+TDE_NO_EXPORT void CallbackProcess::processStopped (TDEProcess *) {
     if (m_source)
         ((PlayListNotify *) m_source)->setInfoMessage (TQString ());
     delete m_backend;
@@ -1584,18 +1584,18 @@ KDE_NO_CDTOR_EXPORT XMLPreferencesPage::XMLPreferencesPage (CallbackProcess * p)
 KDE_NO_CDTOR_EXPORT XMLPreferencesPage::~XMLPreferencesPage () {
 }
 
-KDE_NO_EXPORT void XMLPreferencesFrame::showEvent (TQShowEvent *) {
+TDE_NO_EXPORT void XMLPreferencesFrame::showEvent (TQShowEvent *) {
     if (!m_process->haveConfig ())
         m_process->getConfigData ();
 }
 
-KDE_NO_EXPORT void XMLPreferencesPage::write (TDEConfig *) {
+TDE_NO_EXPORT void XMLPreferencesPage::write (TDEConfig *) {
 }
 
-KDE_NO_EXPORT void XMLPreferencesPage::read (TDEConfig *) {
+TDE_NO_EXPORT void XMLPreferencesPage::read (TDEConfig *) {
 }
 
-KDE_NO_EXPORT void XMLPreferencesPage::sync (bool fromUI) {
+TDE_NO_EXPORT void XMLPreferencesPage::sync (bool fromUI) {
     if (!m_configframe) return;
     TQTable * table = m_configframe->table;
     int row = 0;
@@ -1663,13 +1663,13 @@ KDE_NO_EXPORT void XMLPreferencesPage::sync (bool fromUI) {
     }
 }
 
-KDE_NO_EXPORT void XMLPreferencesPage::prefLocation (TQString & item, TQString & icon, TQString & tab) {
+TDE_NO_EXPORT void XMLPreferencesPage::prefLocation (TQString & item, TQString & icon, TQString & tab) {
     item = i18n ("General Options");
     icon = TQString ("kmplayer");
     tab = m_process->menuName ();
 }
 
-KDE_NO_EXPORT TQFrame * XMLPreferencesPage::prefPage (TQWidget * parent) {
+TDE_NO_EXPORT TQFrame * XMLPreferencesPage::prefPage (TQWidget * parent) {
     m_configframe = new XMLPreferencesFrame (parent, m_process);
     return m_configframe;
 }
@@ -1766,7 +1766,7 @@ KDE_NO_CDTOR_EXPORT GStreamer::GStreamer (TQObject * parent, Settings * settings
 
 KDE_NO_CDTOR_EXPORT GStreamer::~GStreamer () {}
 
-KDE_NO_EXPORT bool GStreamer::ready (Viewer * viewer) {
+TDE_NO_EXPORT bool GStreamer::ready (Viewer * viewer) {
     initProcess (viewer);
     viewer->changeProtocol (QXEmbed::XPLAIN);
     m_request_seek = -1;
@@ -1816,7 +1816,7 @@ FFMpeg::FFMpeg (TQObject * parent, Settings * settings)
 KDE_NO_CDTOR_EXPORT FFMpeg::~FFMpeg () {
 }
 
-KDE_NO_EXPORT void FFMpeg::init () {
+TDE_NO_EXPORT void FFMpeg::init () {
 }
 
 bool FFMpeg::deMediafiedPlay () {
@@ -1867,7 +1867,7 @@ bool FFMpeg::deMediafiedPlay () {
     return m_process->isRunning ();
 }
 
-KDE_NO_EXPORT bool FFMpeg::stop () {
+TDE_NO_EXPORT bool FFMpeg::stop () {
     terminateJobs ();
     if (!playing ()) return true;
     kdDebug () << "FFMpeg::stop" << endl;
@@ -1875,7 +1875,7 @@ KDE_NO_EXPORT bool FFMpeg::stop () {
     return true;
 }
 
-KDE_NO_EXPORT bool FFMpeg::quit () {
+TDE_NO_EXPORT bool FFMpeg::quit () {
     stop ();
     if (!playing ()) return true;
     TQTime t;
@@ -1886,7 +1886,7 @@ KDE_NO_EXPORT bool FFMpeg::quit () {
     return Process::quit ();
 }
 
-KDE_NO_EXPORT void FFMpeg::processStopped (TDEProcess *) {
+TDE_NO_EXPORT void FFMpeg::processStopped (TDEProcess *) {
     setState (NotRunning);
 }
 
@@ -2014,7 +2014,7 @@ KDE_NO_CDTOR_EXPORT NpStream::~NpStream () {
     close ();
 }
 
-KDE_NO_EXPORT void NpStream::open () {
+TDE_NO_EXPORT void NpStream::open () {
     kdDebug () << "NpStream " << stream_id << " open " << url.url () << endl;
     if (url.url().startsWith ("javascript:")) {
         NpPlayer *npp = static_cast <NpPlayer *> (parent ());
@@ -2046,7 +2046,7 @@ KDE_NO_EXPORT void NpStream::open () {
     }
 }
 
-KDE_NO_EXPORT void NpStream::close () {
+TDE_NO_EXPORT void NpStream::close () {
     if (job) {
         job->kill (); // quiet, no result signal
         job = 0L;
@@ -2055,14 +2055,14 @@ KDE_NO_EXPORT void NpStream::close () {
     }
 }
 
-KDE_NO_EXPORT void NpStream::slotResult (TDEIO::Job *jb) {
+TDE_NO_EXPORT void NpStream::slotResult (TDEIO::Job *jb) {
     kdDebug() << "slotResult " << bytes << " err:" << jb->error () << endl;
     finish_reason = jb->error () ? BecauseError : BecauseDone;
     job = 0L; // signal TDEIO::Job::result deletes itself
     emit stateChanged ();
 }
 
-KDE_NO_EXPORT void NpStream::slotData (TDEIO::Job*, const TQByteArray& qb) {
+TDE_NO_EXPORT void NpStream::slotData (TDEIO::Job*, const TQByteArray& qb) {
     pending_buf = qb; // we suspend job, so qb should be valid until resume
     if (qb.size()) {
         job->suspend ();
@@ -2071,7 +2071,7 @@ KDE_NO_EXPORT void NpStream::slotData (TDEIO::Job*, const TQByteArray& qb) {
     }
 }
 
-KDE_NO_EXPORT void NpStream::redirection (TDEIO::Job *, const KURL &u) {
+TDE_NO_EXPORT void NpStream::redirection (TDEIO::Job *, const KURL &u) {
     url = u;
     emit redirected (stream_id, url);
 }
@@ -2111,10 +2111,10 @@ KDE_NO_CDTOR_EXPORT NpPlayer::~NpPlayer () {
     }
 }
 
-KDE_NO_EXPORT void NpPlayer::init () {
+TDE_NO_EXPORT void NpPlayer::init () {
 }
 
-KDE_NO_EXPORT void NpPlayer::initProcess (Viewer * viewer) {
+TDE_NO_EXPORT void NpPlayer::initProcess (Viewer * viewer) {
     Process::initProcess (viewer);
     connect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
             this, TQ_SLOT (processStopped (TDEProcess *)));
@@ -2165,7 +2165,7 @@ KDE_NO_EXPORT void NpPlayer::initProcess (Viewer * viewer) {
     }
 }
 
-KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
+TDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
     kdDebug() << "NpPlayer::play '" << m_url << "'" << endl;
     // if we change from XPLAIN to XEMBED, the DestroyNotify may come later 
     viewer ()->changeProtocol (QXEmbed::XEMBED);
@@ -2249,7 +2249,7 @@ KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
     return false;
 }
 
-KDE_NO_EXPORT bool NpPlayer::ready (Viewer * viewer) {
+TDE_NO_EXPORT bool NpPlayer::ready (Viewer * viewer) {
     if (playing ())
         return true; // wait for callback
     initProcess (viewer);
@@ -2267,13 +2267,13 @@ KDE_NO_EXPORT bool NpPlayer::ready (Viewer * viewer) {
     return m_process->isRunning ();
 }
 
-KDE_NO_EXPORT void NpPlayer::setStarted (const TQString & srv) {
+TDE_NO_EXPORT void NpPlayer::setStarted (const TQString & srv) {
     remote_service = srv;
     kdDebug () << "NpPlayer::setStarted " << srv << endl;
     setState (Ready);
 }
 
-KDE_NO_EXPORT TQString NpPlayer::evaluateScript (const TQString & script) {
+TDE_NO_EXPORT TQString NpPlayer::evaluateScript (const TQString & script) {
     TQString result;
     emit evaluate (script, result);
     //kdDebug () << "evaluateScript " << script << " => " << result << endl;
@@ -2295,7 +2295,7 @@ static int getStreamId (const TQString &path) {
     return sid;
 }
 
-KDE_NO_EXPORT
+TDE_NO_EXPORT
 void NpPlayer::requestStream (const TQString &path, const TQString & url, const TQString & target) {
     KURL uri (m_base_url.isEmpty () ? m_url : m_base_url, url);
     kdDebug () << "NpPlayer::request " << path << " '" << uri << "'" << endl;
@@ -2327,7 +2327,7 @@ void NpPlayer::requestStream (const TQString &path, const TQString & url, const
     }
 }
 
-KDE_NO_EXPORT void NpPlayer::destroyStream (const TQString &s) {
+TDE_NO_EXPORT void NpPlayer::destroyStream (const TQString &s) {
     int sid = getStreamId (s);
     if (sid >= 0 && streams.contains ((TQ_UINT32) sid)) {
         NpStream *ns = streams[(TQ_UINT32) sid];
@@ -2339,7 +2339,7 @@ KDE_NO_EXPORT void NpPlayer::destroyStream (const TQString &s) {
     }
 }
 
-KDE_NO_EXPORT
+TDE_NO_EXPORT
 void NpPlayer::sendFinish (TQ_UINT32 sid, TQ_UINT32 bytes, NpStream::Reason because) {
     if (playing () && dbus_static->dbus_connnection) {
         TQ_UINT32 reason = (int) because;
@@ -2360,7 +2360,7 @@ void NpPlayer::sendFinish (TQ_UINT32 sid, TQ_UINT32 bytes, NpStream::Reason beca
     }
 }
 
-KDE_NO_EXPORT void NpPlayer::terminateJobs () {
+TDE_NO_EXPORT void NpPlayer::terminateJobs () {
     Process::terminateJobs ();
     const StreamMap::iterator e = streams.end ();
     for (StreamMap::iterator i = streams.begin (); i != e; ++i)
@@ -2368,7 +2368,7 @@ KDE_NO_EXPORT void NpPlayer::terminateJobs () {
     streams.clear ();
 }
 
-KDE_NO_EXPORT bool NpPlayer::stop () {
+TDE_NO_EXPORT bool NpPlayer::stop () {
     terminateJobs ();
     if (!playing ()) return true;
     kdDebug () << "NpPlayer::stop " << endl;
@@ -2386,7 +2386,7 @@ KDE_NO_EXPORT bool NpPlayer::stop () {
     return true;
 }
 
-KDE_NO_EXPORT bool NpPlayer::quit () {
+TDE_NO_EXPORT bool NpPlayer::quit () {
     if (playing ()) {
         stop ();
         TQTime t;
@@ -2399,25 +2399,25 @@ KDE_NO_EXPORT bool NpPlayer::quit () {
     return true;
 }
 
-KDE_NO_EXPORT void NpPlayer::processOutput (TDEProcess *, char * str, int slen) {
+TDE_NO_EXPORT void NpPlayer::processOutput (TDEProcess *, char * str, int slen) {
     if (viewer () && slen > 0)
         viewer ()->view ()->addText (TQString::fromLocal8Bit (str, slen));
 }
 
-KDE_NO_EXPORT void NpPlayer::processStopped (TDEProcess *) {
+TDE_NO_EXPORT void NpPlayer::processStopped (TDEProcess *) {
     terminateJobs ();
     if (m_source)
         ((PlayListNotify *) m_source)->setInfoMessage (TQString ());
     setState (NotRunning);
 }
 
-KDE_NO_EXPORT void NpPlayer::streamStateChanged () {
+TDE_NO_EXPORT void NpPlayer::streamStateChanged () {
     setState (Playing); // hmm, this doesn't really fit in current states
     if (!write_in_progress)
         processStreams ();
 }
 
-KDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32 sid, const KURL &u) {
+TDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32 sid, const KURL &u) {
     if (playing () && dbus_static->dbus_connnection) {
         kdDebug() << "redirected " << sid << " to " << u.url() << endl;
         char *cu = strdup (u.url ().local8Bit().data ());
@@ -2436,7 +2436,7 @@ KDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32 sid, const KURL &u) {
     }
 }
 
-KDE_NO_EXPORT void NpPlayer::processStreams () {
+TDE_NO_EXPORT void NpPlayer::processStreams () {
     NpStream *stream = 0L;
     TQ_UINT32 stream_id;
     timeval tv = { 0x7fffffff, 0 };
@@ -2520,13 +2520,13 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
     }
 }
 
-KDE_NO_EXPORT void NpPlayer::wroteStdin (TDEProcess *) {
+TDE_NO_EXPORT void NpPlayer::wroteStdin (TDEProcess *) {
     write_in_progress = false;
     if (playing ())
         processStreams ();
 }
 
-KDE_NO_EXPORT TQString NpPlayer::menuName () const {
+TDE_NO_EXPORT TQString NpPlayer::menuName () const {
     return i18n ("&Ice Ape");
 }
 
@@ -2547,20 +2547,20 @@ KDE_NO_CDTOR_EXPORT
 NpPlayer::NpPlayer (TQObject * parent, Settings * settings, const TQString &)
  : Process (parent, settings, "npp") {}
 KDE_NO_CDTOR_EXPORT NpPlayer::~NpPlayer () {}
-KDE_NO_EXPORT void NpPlayer::init () {}
-KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () { return false; }
-KDE_NO_EXPORT void NpPlayer::initProcess (Viewer *) {}
-KDE_NO_EXPORT TQString NpPlayer::menuName () const { return TQString (); }
-KDE_NO_EXPORT void NpPlayer::setStarted (const TQString &) {}
-KDE_NO_EXPORT bool NpPlayer::stop () { return false; }
-KDE_NO_EXPORT bool NpPlayer::quit () { return false; }
-KDE_NO_EXPORT bool NpPlayer::ready (Viewer *) { return false; }
-KDE_NO_EXPORT void NpPlayer::processOutput (TDEProcess *, char *, int) {}
-KDE_NO_EXPORT void NpPlayer::processStopped (TDEProcess *) {}
-KDE_NO_EXPORT void NpPlayer::wroteStdin (TDEProcess *) {}
-KDE_NO_EXPORT void NpPlayer::streamStateChanged () {}
-KDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32, const KURL &) {}
-KDE_NO_EXPORT void NpPlayer::terminateJobs () {}
+TDE_NO_EXPORT void NpPlayer::init () {}
+TDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () { return false; }
+TDE_NO_EXPORT void NpPlayer::initProcess (Viewer *) {}
+TDE_NO_EXPORT TQString NpPlayer::menuName () const { return TQString (); }
+TDE_NO_EXPORT void NpPlayer::setStarted (const TQString &) {}
+TDE_NO_EXPORT bool NpPlayer::stop () { return false; }
+TDE_NO_EXPORT bool NpPlayer::quit () { return false; }
+TDE_NO_EXPORT bool NpPlayer::ready (Viewer *) { return false; }
+TDE_NO_EXPORT void NpPlayer::processOutput (TDEProcess *, char *, int) {}
+TDE_NO_EXPORT void NpPlayer::processStopped (TDEProcess *) {}
+TDE_NO_EXPORT void NpPlayer::wroteStdin (TDEProcess *) {}
+TDE_NO_EXPORT void NpPlayer::streamStateChanged () {}
+TDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32, const KURL &) {}
+TDE_NO_EXPORT void NpPlayer::terminateJobs () {}
 
 #endif
 
